searchData={"items":[{"type":"module","title":"IO.ANSI.Table","doc":"Writes data to `:stdio` in a table with borders and colors.\nCan choose a table style to change the look of the table.\n\n###","ref":"IO.ANSI.Table.html"},{"type":"module","title":"Inspired by the book [Programming Elixir](https://pragprog.com/book/elixir16/programming-elixir-1-6) by Dave Thomas. - IO.ANSI.Table","doc":"","ref":"IO.ANSI.Table.html#module-inspired-by-the-book-programming-elixir-https-pragprog-com-book-elixir16-programming-elixir-1-6-by-dave-thomas"},{"type":"function","title":"IO.ANSI.Table.format/2","doc":"Sends a request to the table spec server identified by option `:spec_name`.\nThe server will write data from `maps` to `:stdio` in a table formatted per\nits spec and `options`.\n\nAlso supports:\n\n  - keywords\n  - structs implementing the [Access](https://hexdocs.pm/elixir/Access.html)\n    behaviour.\n\nDoes not support:\n\n  - _nested_ maps, keywords or structs\n\nSee `IO.ANSI.Table.Options` for a list of all options in this API.","ref":"IO.ANSI.Table.html#format/2"},{"type":"function","title":"Parameters - IO.ANSI.Table.format/2","doc":"- `maps`    - _flat_ maps/keywords/structs (list)\n  - `options` - up to `6` options (keyword)","ref":"IO.ANSI.Table.html#format/2-parameters"},{"type":"function","title":"Options - IO.ANSI.Table.format/2","doc":"- `:async`     - whether to write the table asynchronously (boolean)\n  - `:bell`      - whether to ring the bell (boolean)\n  - `:count`     - number of `maps` to format (integer)\n  - `:max_width` - to cap column widths (non neg integer)\n  - `:spec_name` - to identify the table spec server (string)\n  - `:style`     - table style (atom)","ref":"IO.ANSI.Table.html#format/2-options"},{"type":"function","title":"Examples - IO.ANSI.Table.format/2","doc":"alias IO.ANSI.Table\n\n    people = [\n      %{name: \"Mike\", likes: \"ski, arts\", dob: \"1992-04-15\", bmi: 23.9},\n      %{name: \"Mary\", likes: \"travels\"  , dob: \"1992-04-15\", bmi: 26.8},\n      %{name: \"Ann\" , likes: \"reading\"  , dob: \"1992-04-15\", bmi: 24.7},\n      %{name: \"Ray\" , likes: \"cycling\"  , dob: \"1977-08-28\", bmi: 19.1},\n      %{name: \"Bill\", likes: \"karate\"   , dob: \"1977-08-28\", bmi: 18.1},\n      %{name: \"Joe\" , likes: \"boxing\"   , dob: \"1977-08-28\", bmi: 20.8},\n      %{name: \"Jill\", likes: \"cooking\"  , dob: \"1976-09-28\", bmi: 25.8}\n    ]\n\n    Table.start([:name, :dob, :likes],\n      header_fixes: %{~r[dob]i => \"Date of Birth\"},\n      sort_specs: [asc: :dob],\n      align_specs: [center: :dob],\n      margins: [top: 2, bottom: 2, left: 2]\n    )\n\n    Table.format(people, style: :light)\n    Table.format(people, style: :light_alt)\n    Table.format(people, style: :light_mult)\n    Table.format(people, style: :cyan_alt)\n    Table.format(people, style: :cyan_mult)\n\n## ![light](images/light.png)\n## ![light_alt](images/light_alt.png)\n## ![light_mult](images/light_mult.png)\n## ![cyan_alt](images/cyan_alt.png)\n## ![cyan_mult](images/cyan_mult.png)","ref":"IO.ANSI.Table.html#format/2-examples"},{"type":"function","title":"IO.ANSI.Table.get_spec/1","doc":"Sends a request to the table spec server identified by option `:spec_name`.\nReturns the server's table spec.\n\nSee `IO.ANSI.Table.Options` for a list of all options in this API.","ref":"IO.ANSI.Table.html#get_spec/1"},{"type":"function","title":"Parameters - IO.ANSI.Table.get_spec/1","doc":"- `options` - up to `1` option (keyword)","ref":"IO.ANSI.Table.html#get_spec/1-parameters"},{"type":"function","title":"Options - IO.ANSI.Table.get_spec/1","doc":"- `:spec_name` - to identify the table spec server (string)","ref":"IO.ANSI.Table.html#get_spec/1-options"},{"type":"function","title":"Examples - IO.ANSI.Table.get_spec/1","doc":"iex> alias IO.ANSI.Table\n    iex> Table.start([:name, :dob, :likes])\n    iex> spec = Table.get_spec()\n    iex> {spec.headers, spec.spec_name}\n    {[:name, :dob, :likes], \"io_ansi_table\"}\n\n    iex> alias IO.ANSI.Table\n    iex> Table.start([:name, :dob, :likes], spec_name: \"members\")\n    iex> spec = Table.get_spec(spec_name: \"members\")\n    iex> {spec.headers, spec.spec_name}\n    {[:name, :dob, :likes], \"members\"}","ref":"IO.ANSI.Table.html#get_spec/1-examples"},{"type":"function","title":"IO.ANSI.Table.start/2","doc":"Starts a new table spec server process and supervises it.\nUpon request (see `format/2`), the server will write data from a list of\nmaps to `:stdio` in a table formatted per `headers` and `options`.\n\nThe table columns are identified by `headers` (`Map` keys).\nWe calculate the width of each column to fit the longest element\nin that column, also considering the column heading.\nHowever, the `:max_width` option prevails.\n\nIf the `:count` option is positive, we format the first _count_\nmaps in the list, once sorted. If negative, the last _count_ ones.\n\nSee `IO.ANSI.Table.Options` for a list of all options in this API.","ref":"IO.ANSI.Table.html#start/2"},{"type":"function","title":"Parameters - IO.ANSI.Table.start/2","doc":"- `headers` - keys identifying each column (list)\n  - `options` - up to `10` options (keyword)","ref":"IO.ANSI.Table.html#start/2-parameters"},{"type":"function","title":"Options - IO.ANSI.Table.start/2","doc":"- `:align_specs`  - to align column elements (list/keyword)\n  - `:bell`         - whether to ring the bell (boolean)\n  - `:count`        - number of maps to format (integer)\n  - `:header_fixes` - to alter the `headers` (map)\n  - `:margins`      - to position the table (keyword)\n  - `:max_width`    - to cap column widths (non neg integer)\n  - `:sort_specs`   - to sort the maps (list/keyword)\n  - `:sort_symbols` - to denote sort direction (keyword)\n  - `:spec_name`    - to identify the table spec server (string)\n  - `:style`        - table style (atom)","ref":"IO.ANSI.Table.html#start/2-options"},{"type":"function","title":"Examples - IO.ANSI.Table.start/2","doc":"iex> alias IO.ANSI.Table\n    iex> alias IO.ANSI.Table.SpecServer\n    iex> {:ok, pid} = Table.start([:name, :dob, :likes], spec_name: \"people\")\n    iex> pid == SpecServer.via(\"people\") |> GenServer.whereis()\n    true","ref":"IO.ANSI.Table.html#start/2-examples"},{"type":"function","title":"IO.ANSI.Table.stop/1","doc":"Stops a table spec server process normally. It won't be restarted.\nThe table spec server to stop is identified by option `:spec_name`.\n\nSee `IO.ANSI.Table.Options` for a list of all options in this API.","ref":"IO.ANSI.Table.html#stop/1"},{"type":"function","title":"Parameters - IO.ANSI.Table.stop/1","doc":"- `options` - up to `1` option (keyword)","ref":"IO.ANSI.Table.html#stop/1-parameters"},{"type":"function","title":"Options - IO.ANSI.Table.stop/1","doc":"- `:spec_name` - to identify the table spec server (string)","ref":"IO.ANSI.Table.html#stop/1-options"},{"type":"function","title":"Examples - IO.ANSI.Table.stop/1","doc":"iex> alias IO.ANSI.Table\n    iex> Table.start([:name, :dob, :likes])\n    iex> Table.stop\n    :ok\n\n    iex> alias IO.ANSI.Table\n    iex> Table.start([:name, :dob, :likes], spec_name: \"stats\")\n    iex> Table.stop(spec_name: \"stats\")\n    :ok","ref":"IO.ANSI.Table.html#stop/1-examples"},{"type":"function","title":"IO.ANSI.Table.write/3","doc":"Writes data from `maps` to `:stdio` in a table formatted per `spec` and\n`options`.\n\nAlso supports:\n\n  - keywords\n  - structs implementing the [Access](https://hexdocs.pm/elixir/Access.html)\n    behaviour\n\nDoes not support:\n\n  - _nested_ maps, keywords or structs\n\nSee `IO.ANSI.Table.Options` for a list of all options in this API.","ref":"IO.ANSI.Table.html#write/3"},{"type":"function","title":"Parameters - IO.ANSI.Table.write/3","doc":"- `spec`    - table spec (struct)\n  - `maps`    - _flat_ maps/keywords/structs (list)\n  - `options` - up to `4` options (keyword)","ref":"IO.ANSI.Table.html#write/3-parameters"},{"type":"function","title":"Options - IO.ANSI.Table.write/3","doc":"- `:bell`      - whether to ring the bell (boolean)\n  - `:count`     - number of `maps` to format (integer)\n  - `:max_width` - to cap column widths (non neg integer)\n  - `:style`     - table style (atom)","ref":"IO.ANSI.Table.html#write/3-options"},{"type":"function","title":"Examples - IO.ANSI.Table.write/3","doc":"alias IO.ANSI.Table\n    alias IO.ANSI.Table.Spec\n\n    people = [\n      %{name: \"Mike\", likes: \"ski, arts\", dob: \"1992-04-15\", bmi: 23.9},\n      %{name: \"Mary\", likes: \"travels\"  , dob: \"1992-04-15\", bmi: 26.8},\n      %{name: \"Ann\" , likes: \"reading\"  , dob: \"1992-04-15\", bmi: 24.7},\n      %{name: \"Ray\" , likes: \"cycling\"  , dob: \"1977-08-28\", bmi: 19.1},\n      %{name: \"Bill\", likes: \"karate\"   , dob: \"1977-08-28\", bmi: 18.1},\n      %{name: \"Joe\" , likes: \"boxing\"   , dob: \"1977-08-28\", bmi: 20.8},\n      %{name: \"Jill\", likes: \"cooking\"  , dob: \"1976-09-28\", bmi: 25.8}\n    ]\n\n    spec = Spec.new([:name, :dob, :likes],\n      header_fixes: %{~r[dob]i => \"Date of Birth\"},\n      sort_specs: [asc: :dob],\n      align_specs: [center: :dob],\n      margins: [top: 2, bottom: 2, left: 2]\n    ) |> Spec.develop()\n\n    Table.write(spec, people, style: :light)\n    Table.write(spec, people, style: :light_alt)\n    Table.write(spec, people, style: :light_mult)\n    Table.write(spec, people, style: :cyan_alt)\n    Table.write(spec, people, style: :cyan_mult)","ref":"IO.ANSI.Table.html#write/3-examples"},{"type":"module","title":"IO.ANSI.Table.Column","doc":"Functions related to the columns of a table.","ref":"IO.ANSI.Table.Column.html"},{"type":"function","title":"IO.ANSI.Table.Column.spread/3","doc":"Spreads a `width` given an `element` and its `align attribute`.","ref":"IO.ANSI.Table.Column.html#spread/3"},{"type":"function","title":"Examples - IO.ANSI.Table.Column.spread/3","doc":"iex> alias IO.ANSI.Table.Column\r\n    iex> {\r\n    ...>   Column.spread(7, \"name\", :left  ),\r\n    ...>   Column.spread(7, \"name\", :center),\r\n    ...>   Column.spread(7, \"name\", :right )\r\n    ...> }\r\n    {[0, 4, 3], [1, 4, 2], [3, 4, 0]}\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> {\r\n    ...>   Column.spread(3, \"name\", :left  ),\r\n    ...>   Column.spread(3, \"name\", :center),\r\n    ...>   Column.spread(3, \"name\", :right )\r\n    ...> }\r\n    {[0, 3, 0], [0, 3, 0], [0, 3, 0]}\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> {\r\n    ...>   Column.spread(10, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :left  ),\r\n    ...>   Column.spread(10, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :center),\r\n    ...>   Column.spread(10, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :right )\r\n    ...> }\r\n    {[0, 21, 3], [1, 21, 2], [3, 21, 0]}\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> {\r\n    ...>   Column.spread(7, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :left  ),\r\n    ...>   Column.spread(7, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :center),\r\n    ...>   Column.spread(7, \"\\e[32m\\e[42mCHEETAH\\e[0m\", :right )\r\n    ...> }\r\n    {[0, 21, 0], [0, 21, 0], [0, 21, 0]}","ref":"IO.ANSI.Table.Column.html#spread/3-examples"},{"type":"function","title":"IO.ANSI.Table.Column.widths/2","doc":"Returns a list of column widths capped by `maximum width`.","ref":"IO.ANSI.Table.Column.html#widths/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Column.widths/2","doc":"iex> alias IO.ANSI.Table.Column\r\n    iex> columns = [[\"cat\", \"wombat\", \"elk\"], [\"mongoose\", \"ant\", \"gnu\"]]\r\n    iex> Column.widths(columns, 99)\r\n    [6, 8]\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> columns = [[\"cat\", \"wombat\", \"elk\"], [\"mongoose\", \"ant\", \"gnu\"]]\r\n    iex> Column.widths(columns, 7)\r\n    [6, 7]\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> columns = [[\"\\e[32m\\e[42mCHEETAH\\e[0m\", \"elk\"], [\"mongoose\", \"ant\"]]\r\n    iex> Column.widths(columns, 99)\r\n    [7, 8]\r\n\r\n    iex> alias IO.ANSI.Table.Column\r\n    iex> columns = [[\"\\e[32m\\e[42mCHEETAH\\e[0m\", \"elk\"], [\"mongoose\", \"ant\"]]\r\n    iex> Column.widths(columns, 6)\r\n    [6, 6]","ref":"IO.ANSI.Table.Column.html#widths/2-examples"},{"type":"type","title":"IO.ANSI.Table.Column.spread/0","doc":"A list of 3 contiguous widths: left width, inner width and right width","ref":"IO.ANSI.Table.Column.html#t:spread/0"},{"type":"type","title":"IO.ANSI.Table.Column.t/0","doc":"Table column","ref":"IO.ANSI.Table.Column.html#t:t/0"},{"type":"type","title":"IO.ANSI.Table.Column.width/0","doc":"Column width","ref":"IO.ANSI.Table.Column.html#t:width/0"},{"type":"module","title":"IO.ANSI.Table.DynSpecSup","doc":"A supervisor that starts table spec server processes dynamically.","ref":"IO.ANSI.Table.DynSpecSup.html"},{"type":"function","title":"IO.ANSI.Table.DynSpecSup.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"IO.ANSI.Table.DynSpecSup.html#child_spec/1"},{"type":"function","title":"IO.ANSI.Table.DynSpecSup.start_link/1","doc":"","ref":"IO.ANSI.Table.DynSpecSup.html#start_link/1"},{"type":"module","title":"IO.ANSI.Table.Header","doc":"Finds the align or sort attribute of a header.\nAlso converts a header into a \"heading\".","ref":"IO.ANSI.Table.Header.html"},{"type":"function","title":"IO.ANSI.Table.Header.find_attr/3","doc":"Finds the align or sort attribute of a `header`.","ref":"IO.ANSI.Table.Header.html#find_attr/3"},{"type":"function","title":"Examples - IO.ANSI.Table.Header.find_attr/3","doc":"iex> alias IO.ANSI.Table.Header\n    iex> sort_specs = [\"dept\", desc: \"hired\"]\n    iex> {\n    ...>   Header.find_attr(\"dept\" , sort_specs, :asc),\n    ...>   Header.find_attr(\"hired\", sort_specs, :asc),\n    ...>   Header.find_attr(\"job\"  , sort_specs, :asc)\n    ...> }\n    {:asc, :desc, nil}\n\n    iex> alias IO.ANSI.Table.Header\n    iex> sort_specs = [\"dept\", desc: {\"hired\", Date}]\n    iex> {\n    ...>   Header.find_attr(\"dept\" , sort_specs, :asc),\n    ...>   Header.find_attr(\"hired\", sort_specs, :asc),\n    ...>   Header.find_attr(\"job\"  , sort_specs, :asc)\n    ...> }\n    {:asc, :desc, nil}\n\n    iex> alias IO.ANSI.Table.Header\n    iex> sort_specs = [{\"hired\", Date}, \"job\", {:desc, \"dept\"}]\n    iex> {\n    ...>   Header.find_attr(\"dept\" , sort_specs, :asc),\n    ...>   Header.find_attr(\"hired\", sort_specs, :asc),\n    ...>   Header.find_attr(\"job\"  , sort_specs, :asc)\n    ...> }\n    {:desc, :asc, :asc}\n\n    iex> alias IO.ANSI.Table.Header\n    iex> sort_specs = [{\"hired\", Date}, desc: \"dept\"]\n    iex> {\n    ...>   Header.find_attr(\"dept\" , sort_specs, :asc),\n    ...>   Header.find_attr(\"hired\", sort_specs, :asc),\n    ...>   Header.find_attr(\"job\"  , sort_specs, :asc)\n    ...> }\n    {:desc, :asc, nil}\n\n    iex> alias IO.ANSI.Table.Header\n    iex> align_specs = [\"dept\", right: \"hired\"]\n    iex> {\n    ...>   Header.find_attr(\"dept\" , align_specs, :left),\n    ...>   Header.find_attr(\"hired\", align_specs, :left),\n    ...>   Header.find_attr(\"job\"  , align_specs, :left)\n    ...> }\n    {:left, :right, nil}","ref":"IO.ANSI.Table.Header.html#find_attr/3-examples"},{"type":"function","title":"IO.ANSI.Table.Header.to_heading/2","doc":"Converts a `header` into a \"heading\".","ref":"IO.ANSI.Table.Header.html#to_heading/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Header.to_heading/2","doc":"iex> alias IO.ANSI.Table.{Header, Spec}\n    iex> spec = Spec.new([:col_4, :col_1, :col_2], sort_specs: [asc: :col_2])\n    iex> Header.to_heading(:col_2, spec)\n    \"Col 2↑\"","ref":"IO.ANSI.Table.Header.html#to_heading/2-examples"},{"type":"type","title":"IO.ANSI.Table.Header.align_attr/0","doc":"Align atribute","ref":"IO.ANSI.Table.Header.html#t:align_attr/0"},{"type":"type","title":"IO.ANSI.Table.Header.align_spec/0","doc":"Align spec","ref":"IO.ANSI.Table.Header.html#t:align_spec/0"},{"type":"type","title":"IO.ANSI.Table.Header.sort_attr/0","doc":"Sort atribute","ref":"IO.ANSI.Table.Header.html#t:sort_attr/0"},{"type":"type","title":"IO.ANSI.Table.Header.sort_spec/0","doc":"Sort spec","ref":"IO.ANSI.Table.Header.html#t:sort_spec/0"},{"type":"type","title":"IO.ANSI.Table.Header.sort_symbol/0","doc":"Sort symbol","ref":"IO.ANSI.Table.Header.html#t:sort_symbol/0"},{"type":"type","title":"IO.ANSI.Table.Header.sym_pos/0","doc":"Symbol position","ref":"IO.ANSI.Table.Header.html#t:sym_pos/0"},{"type":"type","title":"IO.ANSI.Table.Header.t/0","doc":"Header","ref":"IO.ANSI.Table.Header.html#t:t/0"},{"type":"module","title":"IO.ANSI.Table.Line","doc":"Formats the lines of a table.","ref":"IO.ANSI.Table.Line.html"},{"type":"function","title":"IO.ANSI.Table.Line.format/3","doc":"Returns an Erlang I/O format (see `:io.format/2`) reflecting `item widths` and\r\n`item attributes`.\r\n\r\nIt consists of a string with control sequences and embedded\r\n[ANSI codes](https://en.wikipedia.org/wiki/ANSI_escape_code)\r\n(escape sequences), if emitting ANSI codes is enabled.\r\n\r\nHere are a few ANSI codes:\r\n\r\n  - light yellow - `\\e[93m`\r\n  - light cyan   - `\\e[96m`\r\n  - reset        - `\\e[0m`","ref":"IO.ANSI.Table.Line.html#format/3"},{"type":"function","title":"Examples - IO.ANSI.Table.Line.format/3","doc":"iex> alias IO.ANSI.Table.Line\r\n    iex> item_widths = [2, 0, 6]\r\n    iex> item_attrs = [:light_yellow, :normal, :light_cyan]\r\n    iex> Line.format(item_widths, item_attrs, true)\r\n    \"\\e[93m~-2ts\\e[0m~-0ts\\e[96m~-6ts\\e[0m~n\"","ref":"IO.ANSI.Table.Line.html#format/3-examples"},{"type":"function","title":"IO.ANSI.Table.Line.item_attrs/2","doc":"Deploys the style attributes of a given line `type` and table `spec`.","ref":"IO.ANSI.Table.Line.html#item_attrs/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Line.item_attrs/2","doc":"iex> alias IO.ANSI.Table.Line\r\n    iex> # We use a map instead of a %Spec{} for conciseness.\r\n    iex> spec = %{style: :medium, sort_attrs: [nil, :asc, nil]}\r\n    iex> type = :header\r\n    iex> Line.item_attrs(type, spec)\r\n    [\r\n      :normal, :gold                , :normal, # left border\r\n      :normal, :canary              , :normal, # non-key column\r\n      :normal, :gold                , :normal, # inner border\r\n      :normal, [:canary, :underline], :normal, # key column\r\n      :normal, :gold                , :normal, # inner border\r\n      :normal, :canary              , :normal, # non-key column\r\n      :normal, :gold                , :normal  # right border\r\n    ]","ref":"IO.ANSI.Table.Line.html#item_attrs/2-examples"},{"type":"function","title":"IO.ANSI.Table.Line.item_widths/3","doc":"Deploys the widths of `elements` for a given line `type` and table `spec`.","ref":"IO.ANSI.Table.Line.html#item_widths/3"},{"type":"function","title":"Examples - IO.ANSI.Table.Line.item_widths/3","doc":"iex> alias IO.ANSI.Table.Line\r\n    iex> # We use a map instead of a %Spec{} for conciseness.\r\n    iex> spec = %{\r\n    ...>   style: :medium,\r\n    ...>   align_attrs: [:right, :center, nil],\r\n    ...>   column_widths: [7, 13, 9]\r\n    ...> }\r\n    iex> dashes = [\"═══════\", \"═════════════\", \"═════════\"]\r\n    iex> elems = [\"Number\", \"Created at\", \"Title\"]\r\n    iex> {Line.item_widths(dashes, :top, spec),\r\n    ...>  Line.item_widths(elems, :header, spec)}\r\n    {[0, 2, 0,  0, 7, 0,  0, 3, 0,  0, 13, 0,  0, 3, 0,  0, 9, 0,  0, 2, 0],\r\n     [0, 1, 1,  1, 6, 0,  1, 1, 1,  1, 10, 2,  1, 1, 1,  0, 5, 4,  1, 1, 0]}","ref":"IO.ANSI.Table.Line.html#item_widths/3-examples"},{"type":"function","title":"IO.ANSI.Table.Line.items/3","doc":"Deploys `elements` by interlacing them with `filler` and `borders`\r\n(left, inner and right).","ref":"IO.ANSI.Table.Line.html#items/3"},{"type":"function","title":"Examples - IO.ANSI.Table.Line.items/3","doc":"iex> alias IO.ANSI.Table.Line\r\n    iex> elements = [\"Number\", \"Created at\", \"Title\"]\r\n    iex> borders = [\"+-\", \"-+-\", \"-+\"]\r\n    iex> Line.items(elements, borders)\r\n    [\r\n      \"\", \"+-\"        , \"\", # filler, left border, filler\r\n      \"\", \"Number\"    , \"\", # filler, element, filler\r\n      \"\", \"-+-\"       , \"\", # filler, inner border, filler\r\n      \"\", \"Created at\", \"\", # filler, element, filler\r\n      \"\", \"-+-\"       , \"\", # filler, inner border, filler\r\n      \"\", \"Title\"     , \"\", # filler, element, filler\r\n      \"\", \"-+\"        , \"\"  # filler, right border, filler\r\n    ]","ref":"IO.ANSI.Table.Line.html#items/3-examples"},{"type":"type","title":"IO.ANSI.Table.Line.elem/0","doc":"Line element","ref":"IO.ANSI.Table.Line.html#t:elem/0"},{"type":"type","title":"IO.ANSI.Table.Line.item/0","doc":"Line item","ref":"IO.ANSI.Table.Line.html#t:item/0"},{"type":"module","title":"IO.ANSI.Table.LineType","doc":"Defines the \"line type\" types.\r\nAlso writes the line(s) of a given \"line type\".","ref":"IO.ANSI.Table.LineType.html"},{"type":"function","title":"IO.ANSI.Table.LineType.write_lines/2","doc":"Writes the line(s) of the given line `type` and table `spec`.","ref":"IO.ANSI.Table.LineType.html#write_lines/2"},{"type":"type","title":"IO.ANSI.Table.LineType.non_row/0","doc":"Non-row line types","ref":"IO.ANSI.Table.LineType.html#t:non_row/0"},{"type":"type","title":"IO.ANSI.Table.LineType.row/0","doc":"Row line types","ref":"IO.ANSI.Table.LineType.html#t:row/0"},{"type":"type","title":"IO.ANSI.Table.LineType.t/0","doc":"Line types","ref":"IO.ANSI.Table.LineType.html#t:t/0"},{"type":"module","title":"IO.ANSI.Table.LineTypes","doc":"Builds a list of line types from a reversed list of non-row/row line types.","ref":"IO.ANSI.Table.LineTypes.html"},{"type":"function","title":"IO.ANSI.Table.LineTypes.from/1","doc":"Builds a list of line types from a reversed list of non-row/row line `types`.","ref":"IO.ANSI.Table.LineTypes.html#from/1"},{"type":"function","title":"Examples - IO.ANSI.Table.LineTypes.from/1","doc":"iex> alias IO.ANSI.Table.LineTypes\r\n    iex> types = Enum.reverse([:top, :header, :separator, :row, :bottom])\r\n    iex> LineTypes.from(types)\r\n    [:top, :header, :separator, [:row], :bottom]\r\n\r\n    iex> alias IO.ANSI.Table.LineTypes\r\n    iex> types = [:top, :header, :separator, :even_row, :odd_row, :bottom]\r\n    iex> types = Enum.reverse(types)\r\n    iex> LineTypes.from(types)\r\n    [:top, :header, :separator, [:even_row, :odd_row], :bottom]\r\n\r\n    iex> alias IO.ANSI.Table.LineTypes\r\n    iex> types = Enum.reverse([:header, :separator, :row_1, :row_2, :row_3])\r\n    iex> LineTypes.from(types)\r\n    [:header, :separator, [:row_1, :row_2, :row_3]]\r\n\r\n    iex> alias IO.ANSI.Table.LineTypes\r\n    iex> types = Enum.reverse(\r\n    ...>   [:header, :separator, :row, :separator, :row_1, :row_2, :row_3]\r\n    ...> )\r\n    iex> LineTypes.from(types)\r\n    [:header, :separator, [:row], :separator, [:row_1, :row_2, :row_3]]","ref":"IO.ANSI.Table.LineTypes.html#from/1-examples"},{"type":"module","title":"IO.ANSI.Table.Log","doc":"","ref":"IO.ANSI.Table.Log.html"},{"type":"function","title":"IO.ANSI.Table.Log.error/2","doc":"","ref":"IO.ANSI.Table.Log.html#error/2"},{"type":"function","title":"IO.ANSI.Table.Log.info/2","doc":"","ref":"IO.ANSI.Table.Log.html#info/2"},{"type":"module","title":"IO.ANSI.Table.Options","doc":"Documents the options and table styles used in the `IO.ANSI.Table` API.","ref":"IO.ANSI.Table.Options.html"},{"type":"module","title":"Options - IO.ANSI.Table.Options","doc":"* `:align_specs` - to align column elements (list of\r\n  [align specs](`t:IO.ANSI.Table.Header.align_spec/0`) where `:left` is the\r\n  default [align attribute](`t:IO.ANSI.Table.Header.align_attr/0`)).\r\n  Defaults to `[]`.\r\n\r\n  ```elixir\r\n  align_specs: [\r\n    center: \"station_id\", right: \"pressure_mb\", right: \"pressure_in\"\r\n  ]\r\n  ```\r\n\r\n  ```elixir\r\n  align_specs: [left: \"station_id\", right: \"wind_mph\"]\r\n  ```\r\n\r\n  ```elixir\r\n  align_specs: [\"station_id\", right: \"wind_mph\"]\r\n  ```\r\n\r\n* `:async` - whether to format the table asynchronously (boolean).\r\n  Defaults to `false`.\r\n\r\n* `:bell` - whether to ring the bell (boolean). Defaults to `false`.\r\n\r\n* `:count` - number of [maps/keywords/structs](`t:Access.container/0`)\r\n  to format (integer). Defaults to `11`.\r\n\r\n  ```elixir\r\n  count: 11 # first 11 sorted `maps`\r\n  ```\r\n\r\n  ```elixir\r\n  count: -11 # last 11 sorted `maps`\r\n  ```\r\n\r\n* `:header_fixes` - to alter the [headers](`t:IO.ANSI.Table.Header.t/0`)\r\n  once changed to \"title case\" (map). Defaults to %{}.\r\n\r\n  ```elixir\r\n  header_fixes: %{\r\n    # \"station_id\" => \"Station ID\"\r\n    ~r[ id$]i       => \" ID\",\r\n    # \"wind_mph\" => \"Wind MPH\"\r\n    ~r[ mph$]i      => \" MPH\",\r\n    # \"observation_time_rfc822\" => \"Observation Time RFC-822\"\r\n    ~r[ rfc(\\d+)$]i => \" RFC-\\\\1\"\r\n  }\r\n  ```\r\n\r\n  ```elixir\r\n  header_fixes: %{\r\n    \" A \"   => \" a \",\r\n    \" An \"  => \" an \",\r\n    \" And \" => \" and \",\r\n    \" At \"  => \" at \",\r\n    \" But \" => \" but \",\r\n    \" By \"  => \" by \",\r\n    \" For \" => \" for \",\r\n    \" Not \" => \" not \",\r\n    \" Of \"  => \" of \",\r\n    \" On \"  => \" on \",\r\n    \" Or \"  => \" or \",\r\n    \" So \"  => \" so \",\r\n    \" The \" => \" the \",\r\n    \" To \"  => \" to \",\r\n    \" Yet \" => \" yet \"\r\n  }\r\n  ```\r\n\r\n* `:margins` - to position the table (keyword). Defaults to\r\n  `[top: 1, bottom: 1, left: 2]`\r\n\r\n  ```elixir\r\n  margins: [ # default margins\r\n    top:    1, # line(s) before table (can be negative)\r\n    bottom: 1, # line(s) after table\r\n    left:   2  # column(s) left of table\r\n  ]\r\n  ```\r\n\r\n  ```elixir\r\n  margins: [ # example of a side-by-side table\r\n    top:    -11, # move cursor up 11 lines!!\r\n    bottom:   1,\r\n    left:    35, # move cursor forward 35 columns!!\r\n  ]\r\n  ```\r\n\r\n* `:max_width` - to cap column widths (non neg integer). Defaults to `99`.\r\n\r\n* `:sort_specs` - to sort the [maps/keywords/structs](`t:Access.container/0`)\r\n  (list of [sort specs](`t:IO.ANSI.Table.Header.sort_spec/0`) where `:asc` is\r\n  the default [sort attribute](`t:IO.ANSI.Table.Header.sort_attr/0`)).\r\n  Defaults to `[]`.\r\n\r\n  ```elixir\r\n  sort_specs: [\"station_id\", \"wind_mph\"]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_specs: [\"station_id\", desc: \"wind_mph\", desc: \"temp_c\"]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_specs: [asc: \"station_id\", desc: \"wind_mph\"]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_specs: [\"dept\", desc: {\"hired\", Date}]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_specs: [{\"hired\", Date}, \"job\", {:desc, \"dept\"}]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_specs: [{\"hired\", Date}, desc: \"dept\"]\r\n  ```\r\n\r\n* `:sort_symbols` - to denote sort direction (keyword list of\r\n  [sort symbols](`t:IO.ANSI.Table.Header.sort_symbol/0`)). Defaults to\r\n  `[asc: \"↑\", desc: \"↓\", pos: :trailing]`.\r\n\r\n  ```elixir\r\n  sort_symbols: [asc: \"↑\", desc: \"↓\", pos: :trailing] # default sort symbols\r\n  ```\r\n\r\n  ```elixir\r\n  sort_symbols: [asc: \" ▲ \", desc: \" ▼ \", pos: [:leading, :trailing]]\r\n  ```\r\n\r\n  ```elixir\r\n  sort_symbols: [asc: \"⬆\", desc: \"⬇\", pos: :leading]\r\n  ```\r\n\r\n* `:spec_name` - to identify the table spec server (string). Defaults to the\r\n  current application name expressed as a string.\r\n\r\n* `:style` - table style (atom). Defaults to `:plain`.\r\n\r\n  ```elixir\r\n  style: :plain # default style\r\n  ```\r\n\r\n  ```elixir\r\n  style: :dark\r\n  ```","ref":"IO.ANSI.Table.Options.html#module-options"},{"type":"module","title":"Table styles - IO.ANSI.Table.Options","doc":"- `:bare`                  - no colors\n  - `:barish`                - like bare but colored\n  - `:cyan`                  - cyan background\n  - `:cyan_alt`              - cyan header, alternating row colors\n  - `:cyan_border`           - light cyan border\n  - `:cyan_mult`             - cyan header, 3 repeating row colors\n  - `:dark`                  - dark colors\n  - `:dark_alt`              - dark colors, alternating row colors\n  - `:dark_mult`             - dark colors, 3 repeating row colors\n  - `:dashed`                - no colors\n  - `:dotted`                - slightly colored\n  - `:dotted_alt`            - slightly colored, alternating row colors\n  - `:dotted_mult`           - slightly colored, 3 repeating row colors\n  - `:game`                  - game board\n  - `:green`                 - green background\n  - `:green_alt`             - green header, alternating row colors\n  - `:green_border`          - light green border\n  - `:green_border_padded`   - light green border with extra padding\n  - `:green_border_unpadded` - light green border without padding\n  - `:green_mult`            - green header, 3 repeating row colors\n  - `:green_padded`          - like green but with extra padding\n  - `:green_unpadded`        - like green but without padding\n  - `:light`                 - light colors\n  - `:light_alt`             - light colors, alternating row colors\n  - `:light_mult`            - light colors, 3 repeating row colors\n  - `:medium`                - medium colors\n  - `:medium_alt`            - medium colors, alternating row colors\n  - `:medium_mult`           - medium colors, 3 repeating row colors\n  - `:mixed`                 - fillers revealed\n  - `:plain`                 - slightly colored\n  - `:pretty`                - multicolored\n  - `:pretty_alt`            - multicolored, alternating row colors\n  - `:pretty_mult`           - multicolored, 3 repeating row colors\n  - `:test`                  - no colors\n  - `:yellow`                - light yellow background\n  - `:yellow_border`         - light yellow border","ref":"IO.ANSI.Table.Options.html#module-table-styles"},{"type":"module","title":"IO.ANSI.Table.Row","doc":"Defines the row type.","ref":"IO.ANSI.Table.Row.html"},{"type":"type","title":"IO.ANSI.Table.Row.t/0","doc":"Table row","ref":"IO.ANSI.Table.Row.html#t:t/0"},{"type":"module","title":"IO.ANSI.Table.Spec","doc":"A table spec struct and functions for the IO ANSI Table app.\r\n\r\nThe table spec struct contains the following fields:\r\n\r\n* initial fields:\r\n\r\n  - `spec_name`,\r\n  - `headers`,\r\n  - `align_specs`,\r\n  - `bell`,\r\n  - `count`,\r\n  - `header_fixes`,\r\n  - `margins`,\r\n  - `max_width`,\r\n  - `sort_specs`,\r\n  - `sort_symbols`,\r\n  - `style`\r\n\r\n* derived fields:\r\n\r\n  - `align_attrs`,\r\n  - `headings`,\r\n  - `left_margin`,\r\n  - `sort_attrs`\r\n\r\n* data dependent fields:\r\n\r\n  - `column_widths`\r\n  - `rows`","ref":"IO.ANSI.Table.Spec.html"},{"type":"function","title":"IO.ANSI.Table.Spec.develop/1","doc":"Updates the derived fields of `spec`.","ref":"IO.ANSI.Table.Spec.html#develop/1"},{"type":"function","title":"IO.ANSI.Table.Spec.new/2","doc":"Creates a table spec struct from `headers` and `options`.","ref":"IO.ANSI.Table.Spec.html#new/2"},{"type":"function","title":"IO.ANSI.Table.Spec.spec_name/1","doc":"Gets the table spec server name in `options`.\r\nDefaults to the current app name expressed as a string.","ref":"IO.ANSI.Table.Spec.html#spec_name/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.spec_name/1","doc":"iex> alias IO.ANSI.Table.Spec\r\n    iex> Spec.spec_name(style: :light, count: 9, spec_name: \"github_issues\")\r\n    \"github_issues\"\r\n\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> Spec.spec_name([])\r\n    \"io_ansi_table\"","ref":"IO.ANSI.Table.Spec.html#spec_name/1-examples"},{"type":"function","title":"IO.ANSI.Table.Spec.write_table/3","doc":"Writes data from `maps` to `:stdio` per table `spec` and `options`.","ref":"IO.ANSI.Table.Spec.html#write_table/3"},{"type":"type","title":"IO.ANSI.Table.Spec.t/0","doc":"A table spec struct for the IO ANSI Table app","ref":"IO.ANSI.Table.Spec.html#t:t/0"},{"type":"module","title":"IO.ANSI.Table.Spec.AlignAttrs","doc":"Derives the align attributes of a table.","ref":"IO.ANSI.Table.Spec.AlignAttrs.html"},{"type":"function","title":"IO.ANSI.Table.Spec.AlignAttrs.derive_and_put/1","doc":"Derives the align attributes of a table.","ref":"IO.ANSI.Table.Spec.AlignAttrs.html#derive_and_put/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.AlignAttrs.derive_and_put/1","doc":"iex> alias IO.ANSI.Table.Spec.AlignAttrs\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2], align_specs: [right: :c2])\r\n    iex> %Spec{align_attrs: align_attrs} = AlignAttrs.derive_and_put(spec)\r\n    iex> align_attrs\r\n    [nil, nil, :right]","ref":"IO.ANSI.Table.Spec.AlignAttrs.html#derive_and_put/1-examples"},{"type":"module","title":"IO.ANSI.Table.Spec.ColumnWidths","doc":"Derives the column widths of a table.","ref":"IO.ANSI.Table.Spec.ColumnWidths.html"},{"type":"function","title":"IO.ANSI.Table.Spec.ColumnWidths.derive_and_put/1","doc":"Derives the column widths of a table.","ref":"IO.ANSI.Table.Spec.ColumnWidths.html#derive_and_put/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.ColumnWidths.derive_and_put/1","doc":"iex> alias IO.ANSI.Table.Spec.{ColumnWidths, Headings, Rows}\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2])\r\n    iex> maps = [%{c1: 11, c2: 12, c4: 14}, %{c1: 21, c2: 22, c4: :r2c4}]\r\n    iex> spec = Headings.derive_and_put(spec)\r\n    iex> spec = Rows.derive_and_put(spec, maps)\r\n    iex> spec = ColumnWidths.derive_and_put(spec)\r\n    iex> %Spec{column_widths: column_widths} = spec\r\n    iex> column_widths\r\n    [4, 2, 2]","ref":"IO.ANSI.Table.Spec.ColumnWidths.html#derive_and_put/1-examples"},{"type":"module","title":"IO.ANSI.Table.Spec.Headings","doc":"Derives the headings of a table.","ref":"IO.ANSI.Table.Spec.Headings.html"},{"type":"function","title":"IO.ANSI.Table.Spec.Headings.derive_and_put/1","doc":"Derives the headings of a table.","ref":"IO.ANSI.Table.Spec.Headings.html#derive_and_put/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.Headings.derive_and_put/1","doc":"iex> alias IO.ANSI.Table.Spec.Headings\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2], sort_specs: [:c4])\r\n    iex> %Spec{headings: headings} = Headings.derive_and_put(spec)\r\n    iex> headings\r\n    [\"C4↑\", \"C1\", \"C2\"]\r\n\r\n    iex> alias IO.ANSI.Table.Spec.Headings\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new(\r\n    ...>   [\"station_id\", \"wind_mph\"],\r\n    ...>   sort_specs: [\"station_id\"],\r\n    ...>   header_fixes: %{\"Id\" => \"ID\", \"Mph\" => \"MPH\"}\r\n    ...> )\r\n    iex> %Spec{headings: headings} = Headings.derive_and_put(spec)\r\n    iex> headings\r\n    [\"Station ID↑\", \"Wind MPH\"]","ref":"IO.ANSI.Table.Spec.Headings.html#derive_and_put/1-examples"},{"type":"module","title":"IO.ANSI.Table.Spec.LeftMargin","doc":"Derives the left margin of a table.","ref":"IO.ANSI.Table.Spec.LeftMargin.html"},{"type":"function","title":"IO.ANSI.Table.Spec.LeftMargin.derive_and_put/1","doc":"Derives the left margin of a table.","ref":"IO.ANSI.Table.Spec.LeftMargin.html#derive_and_put/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.LeftMargin.derive_and_put/1","doc":"iex> alias IO.ANSI.Table.Spec.LeftMargin\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2], margins: [left: 3])\r\n    iex> %Spec{left_margin: left_margin} = LeftMargin.derive_and_put(spec)\r\n    iex> left_margin\r\n    \"\u001B[3C\"\r\n\r\n    iex> alias IO.ANSI.Table.Spec.LeftMargin\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2], margins: [left: 0])\r\n    iex> %Spec{left_margin: left_margin} = LeftMargin.derive_and_put(spec)\r\n    iex> left_margin\r\n    \"\"","ref":"IO.ANSI.Table.Spec.LeftMargin.html#derive_and_put/1-examples"},{"type":"module","title":"IO.ANSI.Table.Spec.Rows","doc":"Derives the rows of a table.\nAlso transposes rows into columns.","ref":"IO.ANSI.Table.Spec.Rows.html"},{"type":"function","title":"IO.ANSI.Table.Spec.Rows.derive_and_put/2","doc":"Derives the rows of a table given `spec` and `maps`.","ref":"IO.ANSI.Table.Spec.Rows.html#derive_and_put/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.Rows.derive_and_put/2","doc":"iex> alias IO.ANSI.Table.Spec.Rows\n    iex> alias IO.ANSI.Table.Spec\n    iex> spec = Spec.new([:c4, :c1, :c2])\n    iex> maps = [%{c1: 11, c2: 12, c4: 14}, %{c1: 21, c2: 22, c4: 24}]\n    iex> %Spec{rows: rows} = Rows.derive_and_put(spec, maps)\n    iex> rows\n    [[\"14\", \"11\", \"12\"], [\"24\", \"21\", \"22\"]]","ref":"IO.ANSI.Table.Spec.Rows.html#derive_and_put/2-examples"},{"type":"function","title":"IO.ANSI.Table.Spec.Rows.transpose/1","doc":"Transposes `rows` into columns.","ref":"IO.ANSI.Table.Spec.Rows.html#transpose/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.Rows.transpose/1","doc":"iex> alias IO.ANSI.Table.Spec.Rows\n    iex> rows = [\n    ...>   [\"1\", \"2\", \"3\"],\n    ...>   [\"4\", \"5\", \"6\"]\n    ...> ]\n    iex> Rows.transpose(rows)\n    [[\"1\", \"4\"], [\"2\", \"5\"], [\"3\", \"6\"]]","ref":"IO.ANSI.Table.Spec.Rows.html#transpose/1-examples"},{"type":"module","title":"IO.ANSI.Table.Spec.SortAttrs","doc":"Derives the sort attributes of a table.","ref":"IO.ANSI.Table.Spec.SortAttrs.html"},{"type":"function","title":"IO.ANSI.Table.Spec.SortAttrs.derive_and_put/1","doc":"Derives the sort attributes of a table.","ref":"IO.ANSI.Table.Spec.SortAttrs.html#derive_and_put/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Spec.SortAttrs.derive_and_put/1","doc":"iex> alias IO.ANSI.Table.Spec.SortAttrs\r\n    iex> alias IO.ANSI.Table.Spec\r\n    iex> spec = Spec.new([:c4, :c1, :c2], sort_specs: [desc: :c2])\r\n    iex> %Spec{sort_attrs: sort_attrs} = SortAttrs.derive_and_put(spec)\r\n    iex> sort_attrs\r\n    [nil, nil, :desc]","ref":"IO.ANSI.Table.Spec.SortAttrs.html#derive_and_put/1-examples"},{"type":"module","title":"IO.ANSI.Table.SpecRecovery","doc":"Makes processes under the spec supervisor fault-tolerant. If any crashes (or\r\nis killed), it is immediately restarted and the system remains undisturbed.","ref":"IO.ANSI.Table.SpecRecovery.html"},{"type":"function","title":"IO.ANSI.Table.SpecRecovery.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"IO.ANSI.Table.SpecRecovery.html#child_spec/1"},{"type":"function","title":"IO.ANSI.Table.SpecRecovery.init/1","doc":"","ref":"IO.ANSI.Table.SpecRecovery.html#init/1"},{"type":"function","title":"IO.ANSI.Table.SpecRecovery.start_link/1","doc":"","ref":"IO.ANSI.Table.SpecRecovery.html#start_link/1"},{"type":"module","title":"IO.ANSI.Table.SpecServer","doc":"A server process that holds a table spec struct as its state.","ref":"IO.ANSI.Table.SpecServer.html"},{"type":"function","title":"IO.ANSI.Table.SpecServer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"IO.ANSI.Table.SpecServer.html#child_spec/1"},{"type":"function","title":"IO.ANSI.Table.SpecServer.init/1","doc":"","ref":"IO.ANSI.Table.SpecServer.html#init/1"},{"type":"function","title":"IO.ANSI.Table.SpecServer.start_link/1","doc":"Spawns a table `spec` server process to be registered via a spec name.","ref":"IO.ANSI.Table.SpecServer.html#start_link/1"},{"type":"function","title":"IO.ANSI.Table.SpecServer.via/1","doc":"Allows to register or look up a table spec server process via a `spec name`.","ref":"IO.ANSI.Table.SpecServer.html#via/1"},{"type":"module","title":"IO.ANSI.Table.SpecSup","doc":"","ref":"IO.ANSI.Table.SpecSup.html"},{"type":"function","title":"IO.ANSI.Table.SpecSup.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"IO.ANSI.Table.SpecSup.html#child_spec/1"},{"type":"function","title":"IO.ANSI.Table.SpecSup.init/1","doc":"","ref":"IO.ANSI.Table.SpecSup.html#init/1"},{"type":"function","title":"IO.ANSI.Table.SpecSup.start_link/1","doc":"","ref":"IO.ANSI.Table.SpecSup.html#start_link/1"},{"type":"module","title":"IO.ANSI.Table.Style","doc":"Defines functions returning various aspects of the configured table styles.","ref":"IO.ANSI.Table.Style.html"},{"type":"function","title":"IO.ANSI.Table.Style.border_attr/2","doc":"Returns the \"border attribute\" of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#border_attr/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.border_attr/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.border_attr(:green, :top)\r\n    [:light_white, :green_background]\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.border_attr(:cyan_alt, :odd_row)\r\n    [:chartreuse_yellow, :chartreuse_yellow_background]","ref":"IO.ANSI.Table.Style.html#border_attr/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.border_spreads/2","doc":"Returns the \"border spreads\" of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#border_spreads/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.border_spreads/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.border_spreads(:plain, :bottom)\r\n    [[0, 2, 0], [0, 3, 0], [0, 2, 0]] # borders: \"└─\", \"─┴─\", \"─┘\"\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.border_spreads(:plain, :header)\r\n    [[0, 1, 1], [1, 1, 1], [1, 1, 0]] # borders: \"│\" ,  \"│\" ,  \"│\"","ref":"IO.ANSI.Table.Style.html#border_spreads/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.borders/2","doc":"Returns the borders of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#borders/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.borders/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.borders(:cyan, :bottom)\r\n    [\"╚═\", \"═╩═\", \"═╝\"]","ref":"IO.ANSI.Table.Style.html#borders/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.dash/2","doc":"Returns the dash of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#dash/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.dash/2","doc":"iex> IO.ANSI.Table.Style\r\n    iex> Style.dash(:dark, :top)\r\n    \"═\"\r\n\r\n    iex> IO.ANSI.Table.Style\r\n    iex> Style.dash(:dark, :row)\r\n    nil","ref":"IO.ANSI.Table.Style.html#dash/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.filler_attr/2","doc":"Returns the \"filler attribute\" of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#filler_attr/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.filler_attr/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.filler_attr(:mixed, :row)\r\n    :green_background\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.filler_attr(:cyan_alt, :odd_row)\r\n    :chartreuse_yellow_background","ref":"IO.ANSI.Table.Style.html#filler_attr/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.from_switch_arg/1","doc":"Converts a switch `argument` into a table style.\r\nE.g. `green-alt` in: `no tx -blt green-alt 11`.","ref":"IO.ANSI.Table.Style.html#from_switch_arg/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.from_switch_arg/1","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.from_switch_arg(\"green-alt\")\r\n    {:ok, :green_alt}\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.from_switch_arg(\"lite\")\r\n    :error","ref":"IO.ANSI.Table.Style.html#from_switch_arg/1-examples"},{"type":"function","title":"IO.ANSI.Table.Style.key_attr/2","doc":"Returns the \"key attribute\" of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#key_attr/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.key_attr/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.key_attr(:light, :row)\r\n    :chartreuse\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.key_attr(:light, :header)\r\n    [:gold, :underline]","ref":"IO.ANSI.Table.Style.html#key_attr/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.line_types/1","doc":"Returns the \"line types\" of a given table `style`.","ref":"IO.ANSI.Table.Style.html#line_types/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.line_types/1","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.line_types(:light)\r\n    [:top, :header, :separator, [:row], :bottom]\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.line_types(:green_alt)\r\n    [:top, :header, :separator, [:even_row, :odd_row]]","ref":"IO.ANSI.Table.Style.html#line_types/1-examples"},{"type":"function","title":"IO.ANSI.Table.Style.non_key_attr/2","doc":"Returns the \"non-key attribute\" of a given table `style` and line `type`.","ref":"IO.ANSI.Table.Style.html#non_key_attr/2"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.non_key_attr/2","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.non_key_attr(:cyan, :row)\r\n    [:black, :cyan_background]","ref":"IO.ANSI.Table.Style.html#non_key_attr/2-examples"},{"type":"function","title":"IO.ANSI.Table.Style.styles/0","doc":"Returns the sorted list of all style IDs.","ref":"IO.ANSI.Table.Style.html#styles/0"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.styles/0","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> length Style.styles\r\n    36\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Enum.take Style.styles, 7\r\n    [:bare, :barish, :cyan, :cyan_alt, :cyan_border, :cyan_mult, :dark]","ref":"IO.ANSI.Table.Style.html#styles/0-examples"},{"type":"function","title":"IO.ANSI.Table.Style.table_styles/0","doc":"Lists all the table styles alphabetically.","ref":"IO.ANSI.Table.Style.html#table_styles/0"},{"type":"function","title":"IO.ANSI.Table.Style.texts/1","doc":"Returns a list of interpolated texts (for all styles) based on `template`.","ref":"IO.ANSI.Table.Style.html#texts/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.texts/1","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.texts(\"  - `&style`&filler - &note\\n\") |> Enum.slice(16..18)\r\n    [\"  - `:green_border`          - light green border\\n\",\r\n     \"  - `:green_border_padded`   - light green border with extra padding\\n\",\r\n     \"  - `:green_border_unpadded` - light green border without padding\\n\"]","ref":"IO.ANSI.Table.Style.html#texts/1-examples"},{"type":"function","title":"Interpolation placeholders - IO.ANSI.Table.Style.texts/1","doc":"- `&style`  - table style (e.g. \":light_alt\")\r\n  - `&arg`    - table style switch arg (e.g. \"light-alt\")\r\n  - `&filler` - padding after &style or &arg\r\n  - `&note`   - table style note\r\n  - `&rank`   - table style rank (3 digits)","ref":"IO.ANSI.Table.Style.html#texts/1-interpolation-placeholders"},{"type":"function","title":"IO.ANSI.Table.Style.to_switch_arg/1","doc":"Converts a table `style` into a switch argument.","ref":"IO.ANSI.Table.Style.html#to_switch_arg/1"},{"type":"function","title":"Examples - IO.ANSI.Table.Style.to_switch_arg/1","doc":"iex> alias IO.ANSI.Table.Style\r\n    iex> Style.to_switch_arg(:green_alt)\r\n    \"green-alt\"\r\n\r\n    iex> alias IO.ANSI.Table.Style\r\n    iex> Style.to_switch_arg(:lite)\r\n    nil","ref":"IO.ANSI.Table.Style.html#to_switch_arg/1-examples"},{"type":"type","title":"IO.ANSI.Table.Style.attr/0","doc":"Style attribute","ref":"IO.ANSI.Table.Style.html#t:attr/0"},{"type":"type","title":"IO.ANSI.Table.Style.border/0","doc":"Table border","ref":"IO.ANSI.Table.Style.html#t:border/0"},{"type":"type","title":"IO.ANSI.Table.Style.t/0","doc":"Table style","ref":"IO.ANSI.Table.Style.html#t:t/0"},{"type":"module","title":"IO.ANSI.Table.TopSup","doc":"","ref":"IO.ANSI.Table.TopSup.html"},{"type":"function","title":"IO.ANSI.Table.TopSup.start/2","doc":"","ref":"IO.ANSI.Table.TopSup.html#start/2"}],"content_type":"text/markdown"}